@@ -45,12 +45,19 @@ extern "C"
 #include <ctype.h> /* for toupper */
 #include <limits.h>
 #include <stdlib.h>
-#include "omc_msvc.h"
+#include "util/omc_msvc.h"
+#include "util/omc_file.h"
 #include "openmodelica.h"
-#include "meta_modelica.h"
+#include "meta/meta_modelica.h"
 #include "ModelicaUtilities.h"
+
 #define ADD_METARECORD_DEFINITIONS static
-#include "OpenModelicaBootstrappingHeader.h"
+#if defined(OMC_BOOTSTRAPPING)
+  #include "../boot/tarball-include/OpenModelicaBootstrappingHeader.h"
+#else
+  #include "../OpenModelicaBootstrappingHeader.h"
+#endif
+
 #include "systemimpl.c"
 
 extern void System_writeFile(const char* filename, const char* data)
@@ -134,21 +141,6 @@ extern int System_realtimeNtick(int ix)
   return rt_ncall(ix);
 }
 
-extern const char* System_getRTLibs()
-{
-  return LDFLAGS_RT;
-}
-
-extern const char* System_getRTLibsSim()
-{
-  return LDFLAGS_RT_SIM;
-}
-
-extern const char* System_getRTLibsFMU()
-{
-  return LDFLAGS_RT_SOURCE_FMU;
-}
-
 extern const char* System_getCCompiler()
 {
   return cc;
@@ -179,21 +171,6 @@ extern const char* System_getCFlags()
   return cflags;
 }
 
-extern const char* System_getExeExt()
-{
-  return CONFIG_EXE_EXT;
-}
-
-extern const char* System_getDllExt()
-{
-  return CONFIG_DLL_EXT;
-}
-
-extern const char* System_os()
-{
-  return CONFIG_OS;
-}
-
 extern const char* System_trim(const char* str, const char* chars_to_remove)
 {
   return SystemImpl__trim(str,chars_to_remove);
@@ -232,26 +209,78 @@ extern const char* System_dirname(const char* str)
   return res;
 }
 
+#if defined(OPENMODELICA_BOOTSTRAPPING_STAGE_1)
+extern const char* System_getRTLibs()
+{
+  return "DUMMY RT LIBS";
+}
+
+extern const char* System_getRTLibsSim()
+{
+  return "DUMMY RT LIBS";
+}
+
+extern const char* System_getRTLibsFMU()
+{
+  return "DUMMY RT LIBS";
+}
+
+extern const char* System_getExeExt()
+{
+  return ".exe";
+}
+
+extern const char* System_getDllExt()
+{
+  return CONFIG_DLL_EXT;
+}
+
+extern const char* System_getMakeCommand()
+{
+  return "make";
+}
+
+extern const char* System_os()
+{
+  return "Windows_NT";
+}
+
 extern const char* System_configureCommandLine()
 {
-  return CONFIGURE_COMMANDLINE;
+  return "Dummy configure";
 }
 
 extern const char* System_platform()
 {
-  return CONFIG_PLATFORM;
+  return "Dummy platform";
 }
 
 extern const char* System_pathDelimiter()
 {
-  return CONFIG_PATH_DELIMITER;
+  return "/";
 }
 
 extern const char* System_groupDelimiter()
 {
-  return CONFIG_GROUP_DELIMITER;
+  return ";";
 }
 
+extern const char* System_getCorbaLibs()
+{
+  return "Dummy CORBA libs";
+}
+
+extern void* System_getRuntimeLibs()
+{
+  return "Dummy system libs";
+}
+
+const char* System_getTriple()
+{
+  return "DEFAULT_TRIPLE";
+}
+#endif
+
 extern int System_strncmp(const char *str1, const char *str2, int len)
 {
   int res= strncmp(str1,str2,len);
@@ -636,16 +665,6 @@ void* System_subDirectories(const char *directory)
 }
 #endif
 
-extern const char* System_getCorbaLibs()
-{
-  return CONFIG_CORBALIBS;
-}
-
-extern void* System_getRuntimeLibs()
-{
-  return CONFIG_SYSTEMLIBS;
-}
-
 extern void* System_regex(const char* str, const char* re, int maxn, int extended, int sensitive, int *nmatch)
 {
   void *res;
@@ -682,9 +701,7 @@ extern char* System_unescapedString(char* str)
 
 extern char* System_unquoteIdentifier(char *str)
 {
-  char *res = SystemImpl__unquoteIdentifier(str);
-  if (res == NULL) return str;
-  return res;
+  return SystemImpl__unquoteIdentifier(str);
 }
 
 extern char* System_getCurrentTimeStr()
@@ -778,11 +795,6 @@ extern void System_getGCStatus(double *used, double *allocated)
   *used = *allocated - GC_get_free_bytes();
 }
 
-extern const char* System_getMakeCommand()
-{
-  return DEFAULT_MAKE;
-}
-
 extern const char* System_snprintff(const char *fmt, int len, double d)
 {
   char *buf;
@@ -818,11 +830,38 @@ extern const char* System_sprintff(const char *fmt, double d)
 
 extern const char* System_realpath(const char *path)
 {
+#if defined(__MINGW32__) || defined(_MSC_VER)
+  MULTIBYTE_TO_WIDECHAR_LENGTH(path, unicodePathLength);
+  MULTIBYTE_TO_WIDECHAR_VAR(path, unicodePath, unicodePathLength);
+
+  DWORD bufLen = 0;
+  bufLen = GetFullPathNameW(unicodePath, bufLen, NULL, NULL);
+  if (!bufLen) {
+    fprintf(stderr, "GetFullPathNameW failed. %lu\n", GetLastError());
+    MMC_THROW();
+  }
+
+  WCHAR unicodeFullPath[bufLen];
+  if (!GetFullPathNameW(unicodePath, bufLen, unicodeFullPath, NULL)) {
+    MULTIBYTE_OR_WIDECHAR_VAR_FREE(unicodePath);
+    fprintf(stderr, "GetFullPathNameW failed. %lu\n", GetLastError());
+    MMC_THROW();
+  }
+  MULTIBYTE_OR_WIDECHAR_VAR_FREE(unicodePath);
+
+  WIDECHAR_TO_MULTIBYTE_LENGTH(unicodeFullPath, bufferLength);
+  WIDECHAR_TO_MULTIBYTE_VAR(unicodeFullPath, buffer, bufferLength);
+  SystemImpl__toWindowsSeperators(buffer, bufferLength);
+  char *res = omc_alloc_interface.malloc_strdup(buffer);
+  MULTIBYTE_OR_WIDECHAR_VAR_FREE(buffer);
+  return res;
+#else
   char buf[PATH_MAX];
   if (realpath(path, buf) == NULL) {
     MMC_THROW();
   }
   return omc_alloc_interface.malloc_strdup(buf);
+#endif
 }
 
 extern int System_fileIsNewerThan(const char *file1, const char *file2)
