@@ -64,11 +64,6 @@
 
 #ifdef WITH_SUNDIALS
 
-/* adrpo: on mingw link with static sundials */
-#if defined(__MINGW32__)
-#define LINK_SUNDIALS_STATIC
-#endif
-
 /* readability */
 #define SCALE_MODE 0
 #define RESCALE_MODE 1
@@ -308,7 +303,7 @@ int ida_solver_initial(DATA* data, threadData_t *threadData,
   }
   infoStreamPrint(LOG_SOLVER, 0, "ida uses internal root finding method %s", solverInfo->solverRootFinding?"YES":"NO");
 
-  /* define maximum integration order of dassl */
+  /* define maximum integration order of ida */
   if (omc_flag[FLAG_MAX_ORDER])
   {
     maxOrder = atoi(omc_flagValue[FLAG_MAX_ORDER]);
@@ -1231,12 +1226,12 @@ int residualFunctionIDA(double time, N_Vector yy, N_Vector yp, N_Vector res, voi
   }
 
   /* debug */
-  if (ACTIVE_STREAM(LOG_DASSL_STATES)){
-    printCurrentStatesVector(LOG_DASSL_STATES, data->localData[0]->realVars, data, time);
-    printVector(LOG_DASSL_STATES, "yprime", data->localData[0]->realVars + data->modelData->nStates, data->modelData->nStates, time);
+  if (ACTIVE_STREAM(LOG_SOLVER_V)){
+    printCurrentStatesVector(LOG_SOLVER_V, data->localData[0]->realVars, data, time);
+    printVector(LOG_SOLVER_V, "yprime", data->localData[0]->realVars + data->modelData->nStates, data->modelData->nStates, time);
     if (idaData->daeMode)
     {
-      printVector(LOG_DASSL_STATES, "yalg", states + data->modelData->nStates, data->simulationInfo->daeModeData->nAlgebraicDAEVars, time);
+      printVector(LOG_SOLVER_V, "yalg", states + data->modelData->nStates, data->simulationInfo->daeModeData->nAlgebraicDAEVars, time);
     }
   }
 
@@ -1493,6 +1488,7 @@ static int jacColoredSymbolicalDense(double currentTime, N_Vector yy,
   const int index = data->callback->INDEX_JAC_A;
   unsigned int i,ii,j, nth;
   SPARSE_PATTERN* sparsePattern = data->simulationInfo->analyticJacobians[index].sparsePattern;
+  ANALYTIC_JACOBIAN* jac = &(data->simulationInfo->analyticJacobians[index]);
 
   /* prepare variables */
   double *states = N_VGetArrayPointer(yy);
@@ -1500,6 +1496,11 @@ static int jacColoredSymbolicalDense(double currentTime, N_Vector yy,
 
   setContext(data, &currentTime, CONTEXT_SYM_JACOBIAN);      /* Reuse jacobian matrix in KLU solver */
 
+  /* Evaluate constant equations if available */
+  if (jac->constantEqns != NULL) {
+      jac->constantEqns(data, threadData, jac, NULL);
+  }
+
 #ifdef USE_PARJAC
   GC_allow_register_threads();
 #endif
@@ -1518,7 +1519,7 @@ static int jacColoredSymbolicalDense(double currentTime, N_Vector yy,
   // These are not the Jacobians of the linear systems! (SimulationInfo->linearSystemData[idx].jacobian)
   ANALYTIC_JACOBIAN* t_jac = &(idaData->jacColumns[omc_get_thread_num()]);
 #else
-  ANALYTIC_JACOBIAN* t_jac = &(data->simulationInfo->analyticJacobians[index]);
+  ANALYTIC_JACOBIAN* t_jac = jac;
 #endif
 
 #pragma omp for
@@ -1791,19 +1792,20 @@ int jacColoredSymbolicalSparse(double currentTime, N_Vector yy, N_Vector yp,
   DATA* data = (DATA*)(((IDA_USERDATA*)idaData->simData)->data);
   threadData_t* threadData = (threadData_t*)(((IDA_USERDATA*)idaData->simData)->threadData);
   const int index = data->callback->INDEX_JAC_A;
+  ANALYTIC_JACOBIAN* jac = &(data->simulationInfo->analyticJacobians[index]);
 
   /* prepare variables */
   double *states = N_VGetArrayPointer(yy);
   double *yprime = N_VGetArrayPointer(yp);
 
 #ifdef USE_PARJAC
-  ANALYTIC_JACOBIAN* jacData = (idaData->jacColumns);
+  ANALYTIC_JACOBIAN* t_jac = (idaData->jacColumns);
 #else
-  ANALYTIC_JACOBIAN* jacData = &(data->simulationInfo->analyticJacobians[index]);
+  ANALYTIC_JACOBIAN* t_jac = jac;
 #endif
-  unsigned int columns = jacData->sizeCols;
-  unsigned int rows = jacData->sizeRows;
-  SPARSE_PATTERN* sparsePattern = jacData->sparsePattern;
+  unsigned int columns = jac->sizeCols;
+  unsigned int rows = jac->sizeRows;
+  SPARSE_PATTERN* sparsePattern = jac->sparsePattern;
   int maxColors = sparsePattern->maxColors;
 
   /* it's needed to clear the matrix */
@@ -1811,7 +1813,12 @@ int jacColoredSymbolicalSparse(double currentTime, N_Vector yy, N_Vector yp,
 
   setContext(data, &currentTime, CONTEXT_SYM_JACOBIAN);      /* Reuse jacobian matrix in KLU solver */
 
-  genericColoredSymbolicJacobianEvaluation(rows, columns, sparsePattern, Jac, jacData,
+  /* Evaluate constant equations if available */
+  if (jac->constantEqns != NULL) {
+      jac->constantEqns(data, threadData, jac, NULL);
+  }
+
+  genericColoredSymbolicJacobianEvaluation(rows, columns, sparsePattern, Jac, t_jac,
                                            data, threadData, &setJacElementKluSparse);
 
   finishSparseColPtr(Jac, sparsePattern->numberOfNoneZeros);
@@ -1997,4 +2004,4 @@ static int idaReScaleData(IDA_SOLVER *idaData)
 }
 
 
-#endif
+#endif /* #ifdef WITH_SUNDIALS */
