@@ -29,11 +29,11 @@
  */
 
 
-#include "ModelicaUtilities.h"
+#include "../ModelicaUtilities.h"
 #include "utility.h"
 #include "modelica_string.h"
-#include "simulation_data.h"
-#include "simulation/options.h"
+#include "../simulation_data.h"
+#include "../simulation/options.h"
 #include <string.h>
 #include <errno.h>
 
@@ -64,7 +64,7 @@ modelica_real real_int_pow(threadData_t *threadData, modelica_real base, modelic
 #if !defined(OMC_MINIMAL_RUNTIME)
 
 #include <regex.h>
-#include "meta/meta_modelica.h"
+#include "../meta/meta_modelica.h"
 
 extern int OpenModelica_regexImpl(const char* str, const char* re, const int maxn, int extended, int ignoreCase, void*(*mystrdup)(const char*), void **outMatches)
 {
@@ -160,15 +160,35 @@ void OpenModelica_updateUriMapping(threadData_t *threadData, void *namesAndDirs)
 
 static const char *PATH_NOT_IN_FMU_RESOURCES = "Returning path (%s) not in the resources directory. The FMU might not work as expected if you send it to a different system";
 
+/* if uri starts with X:\ or X:/ */
+static int hasDriveLetter(const char* uri)
+{
+  return strlen(uri) > 2 &&
+         ((uri[0] >= 'A' && uri[0] <= 'Z') || (uri[0] >= 'a' && uri[0] <= 'z')) &&
+         uri[1]==':' && (uri[2] == '/' || uri[2] == '\\');
+}
+
 static modelica_string uriToFilenameRegularPaths(modelica_string uri_om, const char *uri, char buf[PATH_MAX], const char *origUri, const char *resourcesDir)
 {
   FILE_INFO info = omc_dummyFileInfo;
   struct stat stat_buf;
-  size_t len;
+  size_t len, i, j = 0;
   int uriExists = 0==stat(uri, &stat_buf);
   if (resourcesDir) {
     if (strlen(resourcesDir)+strlen(uri)+2 < PATH_MAX) {
-      sprintf(buf, "%s/%s", resourcesDir, uri);
+      if (hasDriveLetter(uri)) {
+        sprintf(buf, "%s/", resourcesDir);
+        len = strlen(buf);
+        for (i = 0; i < strlen(uri); i++)
+          if (uri[i] != ':')
+          {
+              buf[len+j] = (uri[i] == '\\') ? '/' : uri[i];
+              j++;
+          }
+        buf[len+j]='\0';
+      } else {
+        sprintf(buf, "%s/%s", resourcesDir, uri);
+      }
       if (!uriExists || 0==stat(buf, &stat_buf)) {
         /* The path with resources prepended either exists or the path without resources does not exist
          * So re-run uriToFilenameRegularPaths with resourcesDir prepended to the URI
@@ -206,7 +226,7 @@ static modelica_string uriToFilenameRegularPaths(modelica_string uri_om, const c
     return (0==strcmp(uri, buf) && uri_om) ? uri_om : mmc_mk_scon(buf);
   }
 
-  if (uri[0]=='/') {
+  if (uri[0]=='/' || hasDriveLetter(uri)) {
     /* Absolute path */
     return uri_om ? uri_om : mmc_mk_scon(uri);
   }
@@ -278,15 +298,15 @@ extern modelica_string OpenModelica_uriToFilename_impl(threadData_t *threadData,
       MMC_THROW();
     }
     if (resourcesDir) {
-      if (strlen(dir)+2+strlen(resourcesDir) >= PATH_MAX) {
-        omc_assert_warning(info, "Path longer than PATH_MAX: %s/%s, ignoring the resourcesDir", dir, resourcesDir);
+      if (MMC_STRLEN(dir)+2+strlen(resourcesDir) >= PATH_MAX) {
+        omc_assert_warning(info, "Path longer than PATH_MAX: %s/%s, ignoring the resourcesDir", MMC_STRINGDATA(dir), resourcesDir);
       } else {
-        int dirExists = 0==stat(dir, &stat_buf);
-        sprintf(buf, "%s/%s", dir, resourcesDir);
+        int dirExists = 0==stat(MMC_STRINGDATA(dir), &stat_buf);
+        sprintf(buf, "%s/%s", MMC_STRINGDATA(dir), resourcesDir);
         if (!dirExists || 0==stat(buf, &stat_buf)) {
-          dir = buf;
+          dir = mmc_mk_scon(buf);
         } else {
-          omc_assert_warning(info, PATH_NOT_IN_FMU_RESOURCES, dir);
+          omc_assert_warning(info, PATH_NOT_IN_FMU_RESOURCES, MMC_STRINGDATA(dir));
         }
       }
     }
