@@ -21,7 +21,7 @@
  * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
  *
  * This program is distributed WITHOUT ANY WARRANTY; without
- * even the implied warranty of  MERCHANTABILITY or FITNESS
+ * even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
  * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
  *
@@ -43,6 +43,7 @@ namespace oms
   class ComRef
   {
   public:
+    ComRef();
     ComRef(const std::string& path);
     ComRef(const char* path);
     ~ComRef();
@@ -60,7 +61,11 @@ namespace oms
     ComRef front() const;
     ComRef pop_front();
 
+    bool hasSuffixStart() const;
+    ComRef popSuffix() const;
+
     const char* c_str() const {return cref;}
+    size_t size() {return strlen(cref);}
     operator std::string() const {return std::string(cref);}
 
   private:
