@@ -39,6 +39,7 @@
 #include "DirectedGraph.h"
 #include "Element.h"
 #include "ExternalModel.h"
+#include "Values.h"
 #include "ResultWriter.h"
 #include "ssd/ConnectorGeometry.h"
 #if !defined(NO_TLM)
@@ -79,13 +80,14 @@ namespace oms
     oms_status_enu_t addSubSystem(const ComRef& cref, oms_system_enu_t type);
     oms_status_enu_t addSubModel(const ComRef& cref, const std::string& fmuPath);
     bool validCref(const ComRef& cref);
-    oms_status_enu_t exportToSSD(pugi::xml_node& node) const;
-    oms_status_enu_t importFromSSD(const pugi::xml_node& node);
+    oms_status_enu_t exportToSSD(pugi::xml_node& node, pugi::xml_node& ssvNode) const;
+    oms_status_enu_t importFromSSD(const pugi::xml_node& node, const std::string& sspVersion);
     virtual oms_status_enu_t exportToSSD_SimulationInformation(pugi::xml_node& node) const = 0;
-    virtual oms_status_enu_t importFromSSD_SimulationInformation(const pugi::xml_node& node) = 0;
+    virtual oms_status_enu_t importFromSSD_SimulationInformation(const pugi::xml_node& node, const std::string& sspVersion) = 0;
     void setGeometry(const ssd::ElementGeometry& geometry) {element.setGeometry(&geometry);}
     oms_status_enu_t addConnector(const ComRef& cref, oms_causality_enu_t causality, oms_signal_type_enu_t type);
     Connector* getConnector(const ComRef& cref);
+    std::string getConnectorOwner(const ComRef& cref) const;
     Connector** getConnectors() {return &connectors[0];}
     BusConnector* getBusConnector(const ComRef& cref);
     oms_status_enu_t addTLMConnection(const ComRef& crefA, const ComRef& crefB, double delay, double alpha, double linearimpedance, double angularimpedance);
@@ -119,9 +121,9 @@ namespace oms
     const std::map<ComRef, System*>& getSubSystems() {return subsystems;}
     const std::map<ComRef, Component*>& getComponents() {return components;}
     oms_status_enu_t updateDependencyGraphs();
-    const DirectedGraph& getInitialUnknownsGraph() {return initialUnknownsGraph;}
-    const DirectedGraph& getOutputsGraph() {return outputsGraph;}
-    oms_status_enu_t exportDependencyGraphs(const std::string& pathInitialization, const std::string& pathSimulation);
+    const DirectedGraph& getInitialUnknownsGraph() {return initializationGraph;}
+    const DirectedGraph& getOutputsGraph() {return eventGraph;}
+    oms_status_enu_t exportDependencyGraphs(const std::string& pathInitialization, const std::string& pathEvent, const std::string& pathSimulation);
     oms_status_enu_t setFaultInjection(const ComRef& signal, oms_fault_type_enu_t faultType, double faultValue);
 
     virtual oms_status_enu_t instantiate() = 0;
@@ -162,7 +164,7 @@ namespace oms
     ctpl::thread_pool& getThreadPool();
 
     std::string getUniqueID() const;
-
+    std::vector<std::string> ssvFileSources;
   protected:
     System(const ComRef& cref, oms_system_enu_t type, Model* parentModel, System* parentSystem, oms_solver_enu_t solverMethod);
 
@@ -170,8 +172,9 @@ namespace oms
     System(System const& copy);            ///< not implemented
     System& operator=(System const& copy); ///< not implemented
 
-    DirectedGraph initialUnknownsGraph;
-    DirectedGraph outputsGraph;
+    DirectedGraph initializationGraph; ///< dependency graph, with all connections, solved at initialization
+    DirectedGraph eventGraph; ///< filtered dependency graph, without parameters, solved at event mode
+    DirectedGraph simulationGraph; ///< filtered dependency graph, with connections of type Real, solved at continuous time mode;
 
     Clock clock;
     unsigned int clock_id;
@@ -195,9 +198,7 @@ namespace oms
     std::map<ComRef, System*> subsystems;
     std::map<ComRef, Component*> components;
 
-    std::map<ComRef, double> realValues;            ///< values of the real connectors
-    std::map<ComRef, int> integerValues;            ///< values of the integer connectors
-    std::map<ComRef, bool> booleanValues;           ///< values of the boolean connectors
+    Values values; ///< system level connectors, parameters and their start values defined before instantiating the FMU and external inputs defined after initialization
 
     Element element;
     std::vector<Connector*> connectors;             ///< last element is always NULL
@@ -209,6 +210,7 @@ namespace oms
     std::vector<Connection*> connections;           ///< last element is always NULL
 
     oms_status_enu_t importFromSSD_ConnectionGeometry(const pugi::xml_node& node, const ComRef& crefA, const ComRef& crefB);
+    oms::ComRef getValidCref(const ComRef& cref);
   };
 }
 
