@@ -21,7 +21,7 @@
  * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
  *
  * This program is distributed WITHOUT ANY WARRANTY; without
- * even the implied warranty of  MERCHANTABILITY or FITNESS
+ * even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
  * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
  *
@@ -32,6 +32,7 @@
 #include "ExternalModel.h"
 #include "Logging.h"
 #include "Element.h"
+#include "ExternalModelInfo.h"
 #include "Types.h"
 #include "ssd/Tags.h"
 
@@ -40,7 +41,7 @@
 #include <iostream>
 
 oms::ExternalModel::ExternalModel(const oms::ComRef& cref, System* parentSystem, const std::string& path, const std::string& startscript)
-  : oms::Component(cref, oms_component_external, parentSystem, path), startscript(startscript)
+  : oms::Component(cref, oms_component_external, parentSystem, path), externalModelInfo(path, startscript)
 {
 }
 
@@ -86,13 +87,14 @@ oms_status_enu_t oms::ExternalModel::getRealParameter(const std::string &var, do
   return oms_status_error;
 }
 
-oms_status_enu_t oms::ExternalModel::exportToSSD(pugi::xml_node& node) const
+oms_status_enu_t oms::ExternalModel::exportToSSD(pugi::xml_node& node, pugi::xml_node& ssvNode) const
 {
+  pugi::xml_node annotations_node = node.append_child(oms::ssp::Draft20180219::ssd::annotations);
+  pugi::xml_node annotation_node = annotations_node.append_child(oms::ssp::Version1_0::ssc::annotation);
+  annotation_node.append_attribute("type") = oms::ssp::Draft20180219::annotation_type;
+
   if (tlmbusconnectors[0])
   {
-    pugi::xml_node annotations_node = node.append_child(oms::ssd::ssd_annotations);
-    pugi::xml_node annotation_node = annotations_node.append_child(oms::ssd::ssd_annotation);
-    annotation_node.append_attribute("type") = oms::annotation_type;
     for (const auto& tlmbusconnector : tlmbusconnectors)
       if (tlmbusconnector)
         tlmbusconnector->exportToSSD(annotation_node);
@@ -100,12 +102,11 @@ oms_status_enu_t oms::ExternalModel::exportToSSD(pugi::xml_node& node) const
 
   node.append_attribute("name") = this->getCref().c_str();
   node.append_attribute("source") = this->getPath().c_str();
-  pugi::xml_node siminfo_node = node.append_child(oms::ssd::ssd_simulation_information);
-  pugi::xml_node annotations_node = siminfo_node.append_child(oms::ssd::ssd_annotations);
-  pugi::xml_node annotation_node = annotations_node.append_child(oms::ssd::ssd_annotation);
-  annotation_node.append_attribute("type") = oms::annotation_type;
-  pugi::xml_node externalmodel_node = annotation_node.append_child(oms::external_model);
-  externalmodel_node.append_attribute("startscript") = this->startscript.c_str();
+  /* ssd:SimulationInformation should be added as vendor specific annotations from Version 1.0 */
+  pugi::xml_node siminfo_node = annotation_node.append_child(oms::ssp::Version1_0::simulation_information);
+
+  pugi::xml_node externalmodel_node = siminfo_node.append_child(oms::ssp::Draft20180219::external_model);
+  externalmodel_node.append_attribute("startscript") = externalModelInfo.getStartScript().c_str();
 
   return oms_status_ok;
 }
