@@ -21,7 +21,7 @@
  * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
  *
  * This program is distributed WITHOUT ANY WARRANTY; without
- * even the implied warranty of  MERCHANTABILITY or FITNESS
+ * even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
  * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
  *
@@ -32,11 +32,12 @@
 #include "SystemTLM.h"
 
 #include "Component.h"
+#include "Flags.h"
 #include "Model.h"
-#include "SystemWC.h"
-#include "Types.h"
 #include "OMTLMSimulatorLib/OMTLMSimulatorLib.h"
 #include "ssd/Tags.h"
+#include "SystemWC.h"
+#include "Types.h"
 
 #include <thread>
 #include <algorithm>
@@ -79,14 +80,15 @@ oms::System* oms::SystemTLM::NewSystem(const oms::ComRef& cref, oms::Model* pare
 
 oms_status_enu_t oms::SystemTLM::exportToSSD_SimulationInformation(pugi::xml_node& node) const
 {
-  pugi::xml_node node_simulation_information = node.append_child(oms::ssd::ssd_simulation_information);
+  pugi::xml_node node_annotations = node.append_child(oms::ssp::Draft20180219::ssd::annotations);
+  pugi::xml_node node_annotation = node_annotations.append_child(oms::ssp::Version1_0::ssc::annotation);
+  node_annotation.append_attribute("type") = oms::ssp::Draft20180219::annotation_type;
 
-  pugi::xml_node node_annotations = node_simulation_information.append_child(oms::ssd::ssd_annotations);
+  /* ssd:SimulationInformation should be added as vendor specific annotations from Version 1.0 */
+  pugi::xml_node node_simulation_information = node_annotation.append_child(oms::ssp::Version1_0::simulation_information);
 
-  pugi::xml_node node_annotation = node_annotations.append_child(oms::ssd::ssd_annotation);
-  node_annotation.append_attribute("type") = oms::annotation_type;
+  pugi::xml_node node_tlm = node_simulation_information.append_child(oms::ssp::Draft20180219::tlm_master);
 
-  pugi::xml_node node_tlm = node_annotation.append_child(oms::tlm_master);
   node_tlm.append_attribute("ip") = address.c_str();
   node_tlm.append_attribute("managerport") = std::to_string(desiredManagerPort).c_str();
   node_tlm.append_attribute("monitorport") = std::to_string(desiredMonitorPort).c_str();
@@ -94,25 +96,49 @@ oms_status_enu_t oms::SystemTLM::exportToSSD_SimulationInformation(pugi::xml_nod
   return oms_status_ok;
 }
 
-oms_status_enu_t oms::SystemTLM::importFromSSD_SimulationInformation(const pugi::xml_node& node)
+oms_status_enu_t oms::SystemTLM::importFromSSD_SimulationInformation(const pugi::xml_node& node, const std::string& sspVersion)
 {
-  pugi::xml_node annotationsNode = node.child(oms::ssd::ssd_annotations);
-  if(annotationsNode) {
-    pugi::xml_node annotationNode = annotationsNode.child(oms::ssd::ssd_annotation);
+  pugi::xml_node annotationsNode = node.child(oms::ssp::Draft20180219::ssd::annotations);
+
+  /*  To handle version = "Draft20180219"*/
+  if(annotationsNode)
+  {
+    pugi::xml_node annotationNode;
+    annotationNode = annotationsNode.child(oms::ssp::Version1_0::ssc::annotation);
+
+    // check for ssd:annotation to support older version, which is a bug
+    if(!annotationNode)
+    {
+      annotationNode = annotationsNode.child(oms::ssp::Draft20180219::ssd::annotation);
+      logWarning_deprecated;
+    }
+
     if(annotationNode && std::string(annotationNode.attribute("type").as_string()) == "org.openmodelica") {
-      pugi::xml_node tlmmasterNode = annotationNode.child("oms:TlmMaster");
-      for (auto it = tlmmasterNode.attributes_begin(); it != tlmmasterNode.attributes_end(); ++it)
-      {
-        std::string name = it->name();
-        if (name == "ip")
-          this->address = it->value();
-        else if(name == "managerport")
-          this->desiredManagerPort = tlmmasterNode.attribute("managerport").as_int();
-        else if(name == "monitorport")
-          this->desiredMonitorPort = tlmmasterNode.attribute("monitorport").as_int();
-      }
+      importFromSSD_SimulationInformationHelper(annotationNode);
     }
   }
+  else
+  {
+    // for version = 1.0
+    importFromSSD_SimulationInformationHelper(node);
+  }
+
+  return oms_status_ok;
+}
+
+oms_status_enu_t oms::SystemTLM::importFromSSD_SimulationInformationHelper(const pugi::xml_node & node)
+{
+  pugi::xml_node tlmmasterNode = node.child("oms::ssp::Draft20180219::tlm_master");
+  for (auto it = tlmmasterNode.attributes_begin(); it != tlmmasterNode.attributes_end(); ++it)
+   {
+     std::string name = it->name();
+     if (name == "ip")
+       this->address = it->value();
+     else if(name == "managerport")
+       this->desiredManagerPort = tlmmasterNode.attribute("managerport").as_int();
+     else if(name == "monitorport")
+       this->desiredMonitorPort = tlmmasterNode.attribute("monitorport").as_int();
+   }
 
   return oms_status_ok;
 }
@@ -141,8 +167,11 @@ oms_status_enu_t oms::SystemTLM::initialize()
   omtlm_setMonitorPort(model, actualMonitorPort);
 
   for(const auto& subsystem : this->getSubSystems()) {
+    if(!singleModel.empty() && singleModel != subsystem.second->getCref().c_str()) {
+        continue;
+    }
     omtlm_addSubModel(model, subsystem.second->getCref().c_str(),"","none");
-    for(int i=0; subsystem.second->getTLMBusConnectors()[i]; ++i) {
+    for(int i=0; subsystem.second->getTLMBusConnectors()[i] && (singleModel==""); ++i) {
       TLMBusConnector *tlmbus = subsystem.second->getTLMBusConnectors()[i];
 
       std::string causality = "input";
@@ -165,6 +194,10 @@ oms_status_enu_t oms::SystemTLM::initialize()
     if(component.second->getType() != oms_component_external)
       continue;
 
+    if(!singleModel.empty() && singleModel != component.second->getCref().c_str()) {
+        continue;
+    }
+
     ExternalModel* externalmodel = reinterpret_cast<ExternalModel*>(component.second);
 
     //Copy external model file to temporary directory
@@ -262,16 +295,13 @@ oms_status_enu_t oms::SystemTLM::stepUntil(double stopTime, void (*cb)(const cha
 
   std::thread *masterThread = new std::thread(&omtlm_simulate, model);
 
-  logInfo("Connecting submodels to manager (threaded)");
+  logInfo("Connecting submodels to manager (sequential)");
   std::string server = address + ":" + std::to_string(actualManagerPort);
-  std::vector<std::thread> fmiConnectThreads;
   for(auto it = getSubSystems().begin(); it!=getSubSystems().end(); ++it) {
     System* subsystem = it->second;
     ComRef syscref = subsystem->getCref();
-    fmiConnectThreads.push_back(std::thread(&oms::SystemTLM::connectToSockets, this, syscref, server));
+    connectToSockets(syscref, server);
   }
-  for(auto &thread : fmiConnectThreads)
-    thread.join();
   for(auto it = getSubSystems().begin(); it!=getSubSystems().end(); ++it) {
     if(find(connectedsubsystems.begin(), connectedsubsystems.end(), it->second->getCref()) == connectedsubsystems.end())
       return logError("Failed to connect TLM subsystem: "+std::string(it->second->getCref()));
@@ -343,7 +373,6 @@ oms_status_enu_t oms::SystemTLM::connectToSockets(const oms::ComRef cref, std::s
   TLMPlugin* plugin = TLMPlugin::CreateInstance();
   pluginsMutex.lock();
   plugins[system] = plugin;
-  pluginsMutex.unlock();
 
   logInfo("Initializing plugin for "+std::string(cref));
 
@@ -353,8 +382,10 @@ oms_status_enu_t oms::SystemTLM::connectToSockets(const oms::ComRef cref, std::s
                    system->getMaximumStepSize(),
                    server)) {
     logError("Error initializing the TLM plugin for "+std::string(cref));
+    pluginsMutex.unlock();
     return oms_status_error;
   }
+  pluginsMutex.unlock();
 
   logInfo("Registering interfaces for "+std::string(cref));
 
@@ -420,6 +451,46 @@ oms_status_enu_t oms::SystemTLM::setPositionAndOrientation(const oms::ComRef &cr
   return oms_status_ok;
 }
 
+oms_status_enu_t oms::SystemTLM::fetchInterfaces(const oms::ComRef &cref,
+                                                 std::vector<std::string> &names,
+                                                 std::vector<int> &dimensions,
+                                                 std::vector<std::string> &domains)
+{
+    if(getComponents().find(cref) == getComponents().end()) {
+      return logError("Sub-model \""+std::string(cref)+"\" not found.");
+    }
+    singleModel = cref.c_str();
+    initialize();
+    singleModel = "";
+    omtlm_fetchInterfaces(model, cref.c_str());
+
+    //Read interface data from interfaceData.xml (generated above)
+    pugi::xml_document doc;
+    pugi::xml_parse_result result = doc.load_file("interfaceData.xml");
+    if(!result) {
+        return logError("reading interface data from interfaceData.xml failed");
+    }
+
+    pugi::xml_node modelDataNode = doc.child("ModelData");
+    if(!modelDataNode) {
+        return logError("\"ModelData\" node not found in interfaceData.xml");
+    }
+
+    pugi::xml_node interfacesNode = modelDataNode.child("Interfaces");
+    if(!interfacesNode) {
+        return logError("\"Interfaces\" node not found in interfaceData.xml");
+    }
+
+    for (pugi::xml_node interfaceNode = interfacesNode.child("Interface"); interfaceNode; interfaceNode = interfaceNode.next_sibling("Interface"))
+    {
+        names.push_back(interfaceNode.attribute("Name").value());
+        dimensions.push_back(interfaceNode.attribute("Dimensions").as_int());
+        domains.push_back(interfaceNode.attribute("Domain").value());
+    }
+
+    return oms_status_ok;
+}
+
 oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
 {
   SystemWC* system = reinterpret_cast<SystemWC*>(getSystem(cref));
@@ -439,15 +510,15 @@ oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
     if(bus->getDimensions() == 1 && bus->getCausality() == oms_causality_input) {
       oms_tlm_sigrefs_signal_t tlmrefs;
       double value;
-      system->getReal(bus->getConnector(tlmrefs.y), value);
+      bus->getReal(tlmrefs.y, value);
       plugin->SetInitialValue(bus->getId(), value);
     }
     else if(bus->getDimensions() == 1 && bus->getCausality() == oms_causality_bidir &&
             bus->getInterpolation() == oms_tlm_coarse_grained) {
       oms_tlm_sigrefs_1d_cg_t tlmrefs;
       double effort,flow;
-      system->getReal(bus->getConnector(tlmrefs.c), effort);
-      system->getReal(bus->getConnector(tlmrefs.v), flow);
+      bus->getReal(tlmrefs.c, effort);
+      bus->getReal(tlmrefs.v, flow);
       plugin->SetInitialForce1D(bus->getId(), effort);
       plugin->SetInitialFlow1D(bus->getId(), flow);
     }
@@ -455,8 +526,8 @@ oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
             bus->getInterpolation() == oms_tlm_fine_grained) {
       oms_tlm_sigrefs_1d_fg_t tlmrefs;
       double effort,flow;
-      system->getReal(bus->getConnector(tlmrefs.c[0]), effort);
-      system->getReal(bus->getConnector(tlmrefs.v), flow);
+      bus->getReal(tlmrefs.c[0], effort);
+      bus->getReal(tlmrefs.v, flow);
       plugin->SetInitialForce1D(bus->getId(), effort);
       plugin->SetInitialFlow1D(bus->getId(), flow);
     }
@@ -465,10 +536,10 @@ oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
       oms_tlm_sigrefs_3d_t tlmrefs;
       std::vector<double> effort(6,0);
       std::vector<double> flow(6,0);
-      system->getReals(bus->getConnectors(tlmrefs.f), effort);
+      bus->getReals(tlmrefs.f, effort);
       std::vector<int> flowrefs = tlmrefs.v;
       flowrefs.insert(flowrefs.end(), tlmrefs.w.begin(), tlmrefs.w.end());
-      system->getReals(bus->getConnectors(flowrefs), flow);
+      bus->getReals(flowrefs, flow);
       plugin->SetInitialForce3D(bus->getId(), effort[0], effort[1], effort[2], effort[3], effort[4], effort[5]);
       plugin->SetInitialFlow3D(bus->getId(), flow[0], flow[1], flow[2], flow[3], flow[4], flow[5]);
     }
@@ -477,10 +548,10 @@ oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
       oms_tlm_sigrefs_3d_cg_t tlmrefs;
       std::vector<double> effort(6,0);
       std::vector<double> flow(6,0);
-      system->getReals(bus->getConnectors(tlmrefs.c), effort);
+      bus->getReals(tlmrefs.c, effort);
       std::vector<int> flowrefs = tlmrefs.v;
       flowrefs.insert(flowrefs.end(), tlmrefs.w.begin(), tlmrefs.w.end());
-      system->getReals(bus->getConnectors(flowrefs), flow);
+      bus->getReals(flowrefs, flow);
       plugin->SetInitialForce3D(bus->getId(), effort[0], effort[1], effort[2], effort[3], effort[4], effort[5]);
       plugin->SetInitialFlow3D(bus->getId(), flow[0], flow[1], flow[2], flow[3], flow[4], flow[5]);
     }
@@ -489,10 +560,10 @@ oms_status_enu_t oms::SystemTLM::updateInitialValues(const oms::ComRef cref)
       oms_tlm_sigrefs_3d_fg_t tlmrefs;
       std::vector<double> effort(6,0);
       std::vector<double> flow(6,0);
-      system->getReals(bus->getConnectors(tlmrefs.c[0]), effort);
+      bus->getReals(tlmrefs.c[0], effort);
       std::vector<int> flowrefs = tlmrefs.v;
       flowrefs.insert(flowrefs.end(), tlmrefs.w.begin(), tlmrefs.w.end());
-      system->getReals(bus->getConnectors(flowrefs), flow);
+      bus->getReals(flowrefs, flow);
       plugin->SetInitialForce3D(bus->getId(), effort[0], effort[1], effort[2], effort[3], effort[4], effort[5]);
       plugin->SetInitialFlow3D(bus->getId(), flow[0], flow[1], flow[2], flow[3], flow[4], flow[5]);
     }
@@ -542,7 +613,7 @@ void oms::SystemTLM::writeToSockets(SystemWC *system, double time, Component* co
     if(bus->getDimensions() == 1 && bus->getCausality() == oms_causality_output) {
       oms_tlm_sigrefs_signal_t tlmrefs;
       double value;
-      system->getReal(bus->getConnector(tlmrefs.y), value);
+      bus->getReal(tlmrefs.y, value);
       plugin->SetValueSignal(id, time, value);
       sendValueToLogger(busLogIds[bus], time, value);
     }
@@ -572,10 +643,10 @@ void oms::SystemTLM::writeToSockets(SystemWC *system, double time, Component* co
       std::vector<double> w(3,0);
       std::vector<double> f(6,0);
 
-      system->getReals(bus->getConnectors(tlmrefs.x), x);
-      system->getReals(bus->getConnectors(tlmrefs.A), A);
-      system->getReals(bus->getConnectors(tlmrefs.v), v);
-      system->getReals(bus->getConnectors(tlmrefs.w), w);
+      bus->getReals(tlmrefs.x, x);
+      bus->getReals(tlmrefs.A, A);
+      bus->getReals(tlmrefs.v, v);
+      bus->getReals(tlmrefs.w, w);
 
       //Important: OMTLMSimulator assumes that GetForce is called
       //before SetMotion, in order to calculate the wave variable
@@ -788,7 +859,13 @@ void oms::SystemTLM::sendValueToLogger(int varId, double time, double value)
 
 oms_status_enu_t oms::SystemTLM::registerSignalsForResultFile(ResultWriter& resultFile)
 {
-  for(auto& system : getSubSystems()) {
+  if (Flags::WallTime())
+    clock_id = resultFile.addSignal(std::string(getFullCref() + ComRef("$wallTime")), "wall-clock time [s]", SignalType_REAL);
+  else
+    clock_id = 0;
+
+  for(auto& system : getSubSystems())
+  {
     TLMBusConnector** tlmbuses = system.second->getTLMBusConnectors();
     for(int i=0; tlmbuses[i]; ++i)
     {
@@ -901,10 +978,18 @@ void oms::SystemTLM::sendValuesToLogger(oms::System *system, double time)
 
 oms_status_enu_t oms::SystemTLM::updateSignals(oms::ResultWriter &resultFile)
 {
-  if(logBuffer.size() == 0)
+  if (logBuffer.size() == 0)
     return oms_status_ok;
 
-  int i=2;  //Start on 2 since two first variables are time and walltime
+  int i = (clock_id) ? 2 : 1;  // TODO: see #596
+
+  if (clock_id)
+  {
+    SignalValue_t wallTime;
+    wallTime.realValue = clock.getElapsedWallTime();
+    resultFile.updateSignal(clock_id, wallTime);
+  }
+
   for(auto& varbuffer : logBuffer) {
     auto& databuffer = varbuffer.second;
     double x1,x2,t1,t2;
